@@ -1,6 +1,6 @@
 use clap::ArgMatches;
 use miette::Result;
-use mit_commit_message_lints::{external, external::Vcs};
+use mit_commit_message_lints::external::Vcs;
 
 use crate::{current_dir, get_vcs};
 
@@ -12,18 +12,17 @@ pub(crate) fn run_on_match(matches: &ArgMatches) -> Option<Result<()>> {
 }
 
 fn run(matches: &ArgMatches) -> Result<()> {
-    let subcommand_args = matches
+    let subcommand = matches
         .subcommand_matches("relates-to")
         .and_then(|x| x.subcommand_matches("template"))
         .unwrap();
-    let is_local = Some("local") == matches.value_of("scope");
+    let is_local = Some("local") == subcommand.value_of("scope");
     let current_dir = current_dir()?;
     let mut vcs = get_vcs(is_local, &current_dir)?;
-    let _toml = external::read_toml(current_dir)?;
 
     vcs.set_str(
         "mit.relate.template",
-        subcommand_args.value_of("template").unwrap(),
+        subcommand.value_of("template").unwrap(),
     )?;
 
     Ok(())
